// -*-C++-*-
//
// File:      Cistream
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Fri Mar  8 16:25:04 MET 2002
//
// Original (from: Jon Brumfitt, Aurora) was heavily depending on old GNUcc
// and did not work with GCC 3 or other compilers.

#ifndef CISTREAM_H
#define CISTREAM_H

#include "CommentBuf.h"
#include <string>
#include <iostream>

// <summary>An std::istream using a CommentBuf</summary>
//
// A Cistream is used like a normal std::istream, except that it strips
// comments and provides member functions for getting the current
// line and its line number.
//
//  <h3>Example</h3> <srcblock>
//      ifstream iss("data");
//      Cistream is(iss.rdbuf());
// </srcblock>
class Cistream : public std::istream
{
public:
  
  // Construct a Cistream using an existing streambuf
  Cistream(std::streambuf* sb);
  ~Cistream(){}
  
//----------------------------------------------------------------------------
#ifndef USE_ISO_COMPLIANT_STD
  typedef int       int_type;
  typedef streampos pos_type;
  typedef streamoff off_type;
  typedef int       openmode;
  typedef char      char_type;
#endif
//----------------------------------------------------------------------------

  // Return number of the current line
  int lineNumber() const { return _cbuf->lineNumber(); }
  
  // Return the current line
  virtual string line() const { return _cbuf->line(); }
    

protected:
    // Member data
    CommentBuf* _cbuf;
};

extern Cistream& ccin;


#endif
