// -*-C++-*-
//
// File:      LayoutParFile.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Tue May 21 14:20:48 MEST 2002

#include "LayoutParFile.h"
#include "ParameterInfo.h"
#include "BoolParameter.h"
#include "ChoiceChildParameters.h"

LayoutParFile::LayoutParFile(ParameterInfo* info) : _info(info) 
{
}

LayoutParFile::~LayoutParFile()
{
}

bool LayoutParFile::create(Layout*& lyt)
{
  if (!_info) return false;

  ColumnLayout* columns = new ColumnLayout;
  lyt=columns;

  list<string> root=_info->rootNames();
  for (list<string>::const_iterator it=root.begin();
       it != root.end();it++) {
    Layout* child=0;
    if (!createParameter(child, _info->parameter(*it))) return false;
    columns->addItem(child);
  }
  return true;
}

bool LayoutParFile::createParameter(Layout*& lyt,Parameter* p)
{
  if (!p) return false;

  /* complex parameter? */
  if (p->children().size()) {
    ChoiceChildParameters& items=p->children();

    // currently we only create enableLayout for:
    if (p->getType() == Parameter::Bool && 
	items["no"].empty() && !items["yes"].empty() ) {
      return createEnableLayout(lyt,p);
    }

    // check wheter any item has children
    bool hasChildren=false;
    for (ChoiceChildParameters::const_iterator it=items.begin();
	 it!=items.end();it++) hasChildren |= !(*it).second.empty();

    if (hasChildren) return createChoiceLayout(lyt,p);
  }

  lyt=new SimpleLayout(p);
  return true;
}

bool LayoutParFile::createEnableLayout(Layout*& lyt,Parameter* p)
{
  EnableLayout* layout = new EnableLayout((BoolParameter*)p);
  lyt=layout;
  ChoiceChildParameters& items=p->children();
  for (list<Parameter*>::const_iterator it=items["yes"].begin();
       it!=items["yes"].end();it++) {
    Layout* child=0;
    
    if (!createParameter(child, *it)) return false;
    layout->addItem(child);
  }

  return true;
}

bool LayoutParFile::createChoiceLayout(Layout*& lyt,Parameter* p)
{
  ChoiceLayout* layout = new ChoiceLayout(p);
  lyt=layout;
  ChoiceChildParameters& items=p->children();
  for (ChoiceChildParameters::const_iterator m=items.begin();
       m!=items.end();m++) {

    // create this choice
    ColumnLayout* choice=new ColumnLayout;
    choice->setName((*m).first);
    layout->addItem(choice);
    
    // populate the choice
    for (list<Parameter*>::const_iterator it=(*m).second.begin();
	 it!=(*m).second.end();it++) {
      Layout* child=0;
      
      if (!createParameter(child, *it)) return false;
      choice->addItem(child);
    }
  }
  return true;
}
