/*****************************************************************************
 *
 *  LayoutPrinter.cc                            XMM Science Analysis Subsystem
 *
 *  Plug-in printer for testing GUI layout classes
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *                 -  Exported by Jorgo Bakker, BSC to layout package
 *
 *  $Id: LayoutPrinter.cc,v 1.3 2002/08/29 15:16:13 jbakker Exp $
 *
 *****************************************************************************/

#include "LayoutPrinter.h"
#include "Parameter.h"
#include "Layout.h"

#include <QuotedString.h>
#include <iostream>
#include <string>

#undef QQ
#define QQ(s) QuotedString(s)

static string Indent(int n) {return string(n,' ');}

//================================================================
//  Class LayoutPrinter
//================================================================

void LayoutPrinter::buildSimple(Layout* layout)
{
    SimpleLayout* s = (SimpleLayout*)layout;
    Parameter* p = s->param();

    (*_os) << Indent(_indent) << "Parameter " << QQ(p->name()) << endl;
}

void LayoutPrinter::buildFrame(Layout* layout)
{
    FrameLayout* p = (FrameLayout*)layout;
    string name = p->name();
    (*_os) << Indent(_indent) << "Frame " << QQ(name) << endl;
    list<Layout*>::const_iterator it = p->items().begin();
    while(it != p->items().end())
        (*it++)->build(new LayoutPrinter(_os,_indent+2));
    (*_os) << Indent(_indent) << "end" << endl;
}

void LayoutPrinter::buildCards(Layout* layout)
{
    (*_os) << Indent(_indent) << "Cards" << endl;
    PagedLayout* p = (PagedLayout*)layout;
    list<Layout*>::const_iterator it = p->items().begin();
    while(it != p->items().end())
    {
        (*_os) << Indent(_indent+2) << "Page " << QQ((*it)->name()) << endl;
	(*it++)->build(new LayoutPrinter(_os,_indent+4));
	(*_os) << Indent(_indent+2) << "end" << endl;
    }
    (*_os) << Indent(_indent) << "end" << endl;
}

void LayoutPrinter::buildRow(Layout* layout)
{
    (*_os) << Indent(_indent)  << "Row" << endl;
    RowLayout* p = (RowLayout*)layout;
    list<Layout*> items = p->items();

    list<Layout*>::iterator it = items.begin();
    while(it != items.end())
        (*it++)->build(new LayoutPrinter(_os,_indent+2));
    (*_os) << Indent(_indent) << "end" << endl;
}

void LayoutPrinter::buildColumn(Layout* layout)
{
    (*_os) << Indent(_indent)  << "Column" << endl;
    ColumnLayout* p = (ColumnLayout*)layout;

    list<Layout*>::const_iterator it = p->items().begin();
    while(it != p->items().end())
        (*it++)->build(new LayoutPrinter(_os,_indent+2));
    (*_os) << Indent(_indent) << "end" << endl;
}

void LayoutPrinter::buildEnable(Layout* layout)
{
    EnableLayout* p = (EnableLayout*)layout;
    string name = p->control()->name();
    (*_os) << Indent(_indent) << "Enable " << QQ(name) << endl;

    list<Layout*>::const_iterator it = p->items().begin();
    while(it != p->items().end())
        (*it++)->build(new LayoutPrinter(_os,_indent+2));
    (*_os) << Indent(_indent) << "end" << endl;
}

void LayoutPrinter::buildChoice(Layout* layout)
{
    (*_os) << Indent(_indent) << "Choice" << endl;
    ChoiceLayout* p = (ChoiceLayout*)layout;
    list<Layout*>::const_iterator it = p->items().begin();
    while(it != p->items().end())
    {
        (*_os) << Indent(_indent+2) << "Page " << QQ((*it)->name()) << endl;
	(*it++)->build(new LayoutPrinter(_os,_indent+4));
	(*_os) << Indent(_indent+2) << "end" << endl;
    }
    (*_os) << Indent(_indent) << "end" << endl;
}
