/******************************************************************************
 * 
 * parselayout.cc                                XMM Science Analysis Subsystem
 * (c) 2000  ESA  -  Written Jorgo Bakker, BSC
 * 
 * Synopsis:    parselayout taskname
 * Requires:    SAS_PATH & SAS_DIR set such that it can find the parameter
 *              and layout file accompanying the task
 * Description: It scans both the taskname.par as well as the taskname.lyt.
 *              Bails out if one of the following conditions is true:
 *              * one of the files does not exist
 *              * one of the files has wrong format
 *              * files do not belong together
 *           
 * Exit status: 0 on success, <>0 on error
 * Output:      A human readable dump of the layout as existing in memory.
 * 
 *****************************************************************************/
#include "ParameterInfo.h"
#include "LayoutPrinter.h"
#include "LYTReader.h"
#include <param.h>
#include <errstr.h>
#include <SasFileLocator.h>

#include <iostream>
#include <string>

int main(int argc, char** argv)
{
  SasFileLocator locator("");
  
  if (argc == 2) { // process taskname
    string taskname(argv[1]);

    // read parameteres
    errHandler.name(taskname);
    openParameters(taskname);

    // read layout file. Note: locator bails out if it cannot find the file
    string layoutFile(taskname + ".lyt");
    string layoutPath(locator.locate("config/" + layoutFile));
    Layout* layout = 0;
    LYTReader reader(gParameters);  
    if(reader.open(layoutPath)) reader.parse(layout);
    else errstr << "Could not open file '"<<layoutPath<<"' for parsing"
		<< Sas::error("OpenForParse");

    // print the layout file
    LayoutBuilder* printer = new LayoutPrinter(&cout);
    layout->build(printer);

    delete layout;
    delete printer;
  }
  else
    errstr << "Missing taskname!" 
	   << "Usage: testParseLayout taskname"
	   << Sas::error("MissingArgument");

  return 0;
}
